import { v4 as uuid } from 'uuid';
import * as Comlink from 'comlink';
import { WebStreamingSyncImplementation } from './WebStreamingSyncImplementation';
import { SharedSyncMessageType } from '../../worker/sync/SharedSyncImplementation';
export class SharedWebStreamingSyncImplementation extends WebStreamingSyncImplementation {
    constructor(options) {
        super(options);
        this.syncTabId = uuid();
        const worker = new SharedWorker(new URL('../../worker/sync/SharedSyncImplementation.worker.js', import.meta.url), {
            /* @vite-ignore */
            name: `shared-sync-${this.webOptions.identifier}`,
            type: 'module'
        });
        const { port } = worker;
        this.stateManager = Comlink.wrap(port);
        port.onmessage = (event) => {
            const { data: { type, payload } } = event;
            if (type !== SharedSyncMessageType.UPDATE || payload.tabId == this.syncTabId) {
                // Don't update from own updates
                return;
            }
            // Don't broadcast this to the shared implementation
            this.internalUpdateStatus(payload);
        };
        // Load the initial state
        this.stateManager.getState().then((state) => {
            this.internalUpdateStatus(state);
        });
    }
    /**
     * Triggers update of sync status without broadcasting to shared sync
     * manager
     */
    internalUpdateStatus(state) {
        return super.updateSyncStatus(state);
    }
    updateSyncStatus(state) {
        super.updateSyncStatus(state);
        // Broadcast this update to shared sync manager
        this.stateManager.updateState(Object.assign(Object.assign({}, state), { tabId: this.syncTabId }));
    }
}
//# sourceMappingURL=SharedWebStreamingSyncImplementation.js.map